<?php

namespace GopNext\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class PercentageAndStructureForBudgetController {
    protected $crudService;
    
    public function __construct($connection, $environment, $service, $util, $crudService) {
        $this->connection   = $connection;
        $this->environment  = $environment;
        $this->service      = $service;
        $this->util         = $util;
        $this->crudService	= $crudService;
    }
    
    public function structureItemChange(Request\DataSet $request, Response $response) {
      $data = $request->getDataSet()->getRows();
      
      try {
        $this->service->beginTransaction();
        foreach ($data as $row) {
          $params = [
            "VRPERCITEMGOP"   => $row["VRPERCITEMGOP"],
            "CDFILIAL"        => $row["CDFILIAL"],
            "NRSEQITEMORCA"   => $row["NRSEQITEMORCA"],
            "CDOPERADOR"      => $this->environment->getCdOperador(),
            "NRORG"           => $this->environment->getNrorg()
          ];
          $this->service->updateOperationalItem($params, $row["NRSEQ"]);
        }
        $this->service->commit();
      } catch (\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
      }
    }
    
    public function detailsOperationalItemsStructure(Request\Filter $request, Response $response) {
        $params = ['NRORG'];
        $conditions = $this->util->prepareConditions($params);
        $filter = $request->getFilterCriteria()->getConditions();
        
        /*
        foreach ($filter as &$item) {
            if ($item["columnName"] === "NRPERIODOORCA" && is_array($item["value"])) {
                $item["value"] = $item["value"]["NRPERIODOORCA"];
            }
        }
        */
        $data = $this->crudService->getFilteredDataSet('detailsOperationalItemsStructure', array_merge($conditions, $filter))->getRows();
		    $response->addDataSet(new DataSet("detailsOperationalItemsStructure", $data));
    }
    
    public function budgetUnits(Request\Filter $request, Response $response) {
        $params = ['CDOPERADOR', 'NRORG'];
        $conditions = $this->util->prepareConditions($params);
        $filter = $request->getFilterCriteria()->getConditions();
        
        /*
        foreach ($filter as &$item) {
            if ($item["columnName"] === "NRPERIODOORCA" && is_array($item["value"])) {
                $item["value"] = $item["value"]["NRPERIODOORCA"];
            }
        }
        */
        $data = $this->crudService->getFilteredDataSet('operationalStructureUnit', array_merge($conditions, $filter))->getRows();
		    $response->addDataSet(new DataSet("budgetUnits", $data));
    }
    
    public function operationalItemStructure(Request\Filter $request, Response $response) {
        $params = ['NRORG'];
        $conditions = $this->util->prepareConditions($params);
        $filter = $request->getFilterCriteria()->getConditions();
        
        /*
        foreach ($filter as &$item) {
            if ($item["columnName"] === "NRPERIODOORCA" && is_array($item["value"])) {
                $item["value"] = $item["value"]["NRPERIODOORCA"];
            }
        }
        */
        $data = $this->crudService->getFilteredDataSet('operationalItemStructure', array_merge($conditions, $filter))->getRows();
		    $response->addDataSet(new DataSet("operationalItemStructure", $data));
    }
}